@@ -5,13 +5,12 @@ from faststream.rabbit import RabbitBroker
 broker = RabbitBroker("amqp://guest:guest@localhost:5672/")
 app = FastStream(broker)
 
-publisher = broker.publisher("response-queue")
-
 
 @broker.subscriber("test-queue")
+@broker.publisher("response-queue")
 async def handle(msg, logger: Logger):
-    await publisher.publish("Response")
     logger.info(msg)
+    return "Response"
 
 
 @broker.subscriber("response-queue")
